bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 10. Aventiure
___________________________________________________ #### Aventivre wie der kvnec gvnther zv wormze #### mit frov prvnhilt prvtte
###### 579 | ### Anderthalp des rines | sach man mit manigen sharn ### den chvnich mit sinen gesten | zv dem stade varn ### ovch sah man da bi zovme | leiten manige meit ### di si enpfahen solden | di waren alle bereit
###### 580 | ### do di von islande | cen sehffen chomen dan ### vnt ovch von nibelvngen | di sifrides man ### si gahent zv dem lande | vmmvezech wart ir hant ### da man des chvniges vrivnde | des stades anderthalben vant
###### 581 | ### nv hoeret ovh disiv maere | von der chvnegin ### vten di richen | wi si div magedin ### frvmte von der bvrge | dar si do selbe reit ### da gewan ein ander chvnde | vil manich riter vnt meit
###### 582 | ### der herzoge gere | crimhilt zvomte dan ### niwar fver daz bvrgetor | sifrit der chvene man ### der mvst ir fverbaz dienen | si was ein shone chint ### des wart im wol gelonet | von der ivnchvrowen sint
###### 583 | ### ortwin der chvne | bi vrov vten reit ### vil gesellechlichen | manich riter vnd meit ### ce so grozem antpfange | des wir wol mvegen iehen ### wart nie so vil der vrowen | bi einander gesaehen
###### 584 | ### vil manich bvhvrt richer | wart da getriben ### von helden loblichen | niht wol daz waere beliben ### vor crimhilt der vil shonen | zv den schiffen dan ### do hvp man von den moeren | manige vrowen wolgetan
###### 585 | ### der chvnich was chomen veber | vnt manich werder gast ### hei waz starcher sheffte | vor den vrowen brast ### man hort da hvrtechlichen | von schilden manigen stoz ### hey waz richer pvkelen | vor gedrange lvt erdoz
###### 586 | ### di vil minnechlichen | stvnden an der habe ### gvnther mit sinen gesten | gie von den shiffen abe ### er fvrte prvnhilden | selb an siner hant ### da lvhte wider einander | vil lieht stein vnt gewant
###### 587 | ### mit vil grozen zvehten | vrov crimhilt do gie ### do si vrovn prvnhilden | von ir gesinde enpfie ### man sach da shapel rvcken | mit liehten henden da ### si sich chvsten beide | daz wart dvrch zvht getan
###### 588 | ### do sprach gezogenliche | crimhilt daz maegedin ### ir svlt zv disen landen | vns willechomen sin ### mir vnt miner mvter | vnt allen di wir han ### der getriwen frivnde | do wart nigen getan
###### 589 | ### di vrowen sich beviengen | mit armen dike hie ### so minnechlich enpfahen | gehorte man noch nie ### so di vrowen baeide | der brvete taten chvnt ### vrov vote vnt ir tohter | di chvsten dicke ir sovzen mvnt
###### 590 | ### do frov prvnnhilt | vol chom vf den sant ### si wart vil minnechlichen | genomen bi der hant ### von waetlichen recken | manich wip wolgetan ### man sach di schonen maegede | vor vrovn prvnnhilde stan
###### 591 | ### e daz ir grvz ergienge | daz was ein lange stvnt ### ia wart da gechvsset | manich rosevarwer mvnt ### noch stvnden bi einander | di chvniges tohter rich ### daz liebte an ce saehene | vil manigem recken lobelich
###### 592 | ### do spaehten mit den ovgen | di e horten iehen ### daz si also shones | niht mer haeten gesaehn ### so di vrowen beide | des iach man ane lvge ### ovch chos man an ir libe | da dehaeiner slahte trvge
###### 593 | ### di vrowen spaehen chvnden | vnt minnechlichen lip ### di lobten dvrch ir shoene | daz gvntheres wip ### do sprachen da di wisen | di haeten iz baz gesaehen ### man moehte crimhilden | vor vrovn prvnnhilden iehen
###### 594 | ### wider einander wol giengen | magt vnt wip ### man sach da vol gecieret | vil manigen shonen lip ### da stvnden siden hvetten | vnd manech rich gcelt ### der was gar erfvellet | vor wormez daz velt
###### 595 | ### vor des chvneges magen | wart dringen da getan ### do hiez man prvnnhilde | vnt criemhilde gan ### vnt mit in alle di vrowen | da man schate vant ### da brahten si di daegene | vzer bvrgvnden lant
###### 596 | ### nv waren ovch di geste | ce rosse alle chomen ### vil manich richiv tiost | dvrch shilt wart genomen ### daz velt begonde stivben | sam ob al daz lant ### mit lovge waer erbrvnnen | da wurden helde wol bechant
###### 597 | ### des da di recken pflagen | daz sach da manich meit ### mich dvnchet daz her sifrit | mit sinen daegen reit ### vil manige widerchaere | fver di hvetten dan ### er fvrt der nibelvnge | tvsent waetlicher man
###### 598 | ### do chom von tronege hagene | als im der wirt geriet ### den bvorhvrt minnechliche | do der helt geshiet ### daz si vngestovbet liezzen | div vil schonen chint ### des wart do von den gesten | gevolget gvetliche sint
###### 599 | ### do sprach der herre gernot | div ros lazet stan ### vnz ez beginne chivelen | so svl wir anevan ### dienen shonen wiben | fvr den palas wit ### so der chvenich welle riten | daz ir vil bereite sit
###### 600 | ### do der bvhvrt was cergangen | veber al daz velt ### do giengen chverzewilen | vnder manich gecelt ### di ritter zv den vrowen | vf hoher vrevden wan ### da vertriben si di stvnde | vnz si wolden riten dan
###### 601 | ### vor abendes nahen | do div svnne nidergie ### vnt ez begonde chvolen | niht langer man daz lie ### sich hvop gegen der bverge | manich man vnt wip ### mit ovgen wart getrivtet | vil maniger shonen vrowen lip
###### 602 | ### da wart von gvten helden | vil chleider ab geriten ### von den hochgemveten | nach des landes siten ### vnze fvr den palas | der chvnich niderstvnt ### da wart gedient den vrowen | so helde hochgemvete tvnt
###### 603 | ### do wurden ovch geshaeiden | di richen chvnegin ### vrov vote vnt ir tohter | di giengen beide hin ### mit ir ingesinde | in ein vil witez gadem ### do horte man allenthalben | ce vrevden grozen chradem
###### 604 | ### gerihtet wart daz gesidele | der chvnich wolde gan ### ce tisshe mit den gesten | do sach man bi im stan ### di shonen prvnnhilde | crone si do trvch ### in des chveneges lande | ia was si rich genvch
###### 605 | ### vil manich hergesidele | mit gvten tavelen bereit ### von spise wart gesezet | als vns ist geseit ### des si da haben solden | wi wenech des gebrast ### do sach man bi dem chvnege | vil manigen herlichen gast
###### 606 | ### des wirtes chameraere | in becken von golde rot ### daz wazer fvr trvogen | des waere lvcel not ### ob iv daz iemen sagte | daz man diente baz ### ce fvrsten hochgecite | ich wolte niht gelovben daz
###### 607 | ### e daz der vogt von rine | wazer do genam ### do tet der herre sifrit | als im do gezam ### er mant in siner triwe | wes er im veriach ### e daz er prvnnhilt | da heime in islande sach
###### 608 | ### er sprach ir svlt gedenchen | des mir swuor iwer hant ### swenne vrov prvnnhilt | choeme in diz lant ### ir gaebet mir iwer swester | wa sint di eide chomen ### ich han an iwer reise | michel arbeit genomen
###### 609 | ### do sprach der chvnich cem gaste | ir habet mich reht ermant ### ia ne sol niht meinaeide | werden des min hant ### ich wil iz iv fvegen | so ich allerbeste chan ### do hiez man criemhilde | ce hove fver den chvnich gan
###### 610 | ### mit ir vil schonen maegden | si chomen fver den sal ### do spranch von einer stiege | giselher ce tal ### nv haeizet widerwenden | disiv maegedin ### niwan min swester eine | sol bi dem chvnege sin
###### 611 | ### do braht man criemhilde | da man den chvnich vant ### do stvnden ritter edele | von maniges fversten lant ### in dem sal witen | man hiez si stille stan ### do was div vrov prvnnhilt | wol hin vnz an den tissch gegan
###### 612 | ### do sprach der kvnich gvnther | swester vil gemeit ### dvrch dine selbe tvgende | lose minen eit ### ich swur dir einen recken | vnt wirdet der din man ### so hastv minen willen | mit vil grozen triwen getan
###### 613 | ### do sprach div maget vil edele | vil lieber brvder min ### ir svlt mich niht pflaegen | ia wil ich immer sin ### swi ir mir gebietet | daz sol sin getan ### ich wil in loben gerne | den ir mir herre gebet ce man
###### 614 | ### von lieber ovgenblicke | wart sifrit varwe rot ### ce dienste sich der recke | vron criemhilde bot ### man hiez si zv einander | an einen rinch do gan ### man vragte ob si gerne naeme | den vil vaetlichen man
###### 615 | ### in magtlichen zvehten | shamte si sich ein teil ### iedoch was gelvcke | vnt sifrit vil geil ### daz si in niht versprechen | wolde al da cehant ### ovch lobte si ce wibe | der edel chvenich von niderlant
###### 616 | ### do er si gelobte | vnt ovch in div meit ### gvetlich vmbevahen | was da vil bereit ### von sifrides armen | daz minnechliche chint ### von helden wart gechvesset | div shone crimhilt sint
###### 617 | ### sich teilte daz gesinde | also daz geshah ### an daz gegensiedele | man sifride sah ### mit criemhilde sitcen | dar diente manich man ### man sach di niebelvnge | mit samt sifride gan
###### 618 | ### der chvnich was gesezen | vnt brvennhilt div meit ### do sah si criemhilde | do ne wart nie so leit ### bi sifride sitzen | weinen si began ### ir vielen heize traehene | vber liehtiv wange dan
###### 619 | ### do sprach der wirt des landes | vil liebiv vrowe min ### warvmbe lat ir trveben | vil liehter ovgen shin ### ir mvget ivch vrevn balde | iv ist vndertan ### min lant vnt mine bvrge | vnt manich waetlicher man
###### 620 | ### ich mach wol balde waeinen | sprach div shoniv meit ### vmb dine svester | ist mir von hercen leit ### di sihe ich nahen sitzen | dem eigenholden din ### daz mvz ich imer weinen | sol si also verdaerbet sin
###### 621 | ### do sprach der chvnich gvnther | ir mvegt wol stille dagen ### ich wil iv zandern ziten | disiv maere sagen ### warvmb ich mine swester | sifride han gegaeben ### ia mach si mit dem recken | immer vrolichen laeben
###### 622 | ### si sprach mich iamert immer | ir shone vnt ovch ir zvht ### wess ich war ich mohte | ich haete gerne flvht ### daz ich iv nimmer wolde | geligen nahen bi ### irn saget mir wavon criemhilt | div sifrides wine si
###### 623 | ### do sprach der chvnich edele | ich tvn iz iv wol bechant ### er hat als wol bverge | als ich vnt witiv lant ### daz wizet sicherliche | er ist ein chvnich rich ### darvmb gan ich im ce minnen | di schonen magt lobelich
###### 624 | ### swaz ir der chvnich sagete | si hete trveben mvt ### do gahte von den rossen | vil manich ritter gvt ### ir bvhvrt wart so herte | daz al div bvrch erdoz ### den wirt bi sinen gesten | vil harte sere verdroz
###### 625 | ### er dahte er laege sanpfer | der schonen vrowen bi ### do was er des gedingen | niht gar in hercen vri ### im mvse von ir schvlden | liebes vil geshaehen ### er begonde vrivntlichen | an vrovn prvnhilde saehen
###### 626 | ### ir ritterschapf di geste | bat man abelan ### der chvnich mit sinem wibe | ce bette wolde gan ### vor des sales stigen | gesamenten si sich sit ### criemhilt vnt prvnnhilt | noch was iz an ir beider nit
###### 627 | ### do chom ir ingesinde | di ne svmten sich des niht ### ir richen chamaeraere | brahten in div lieht ### sich teilten do di recken | der zweir chvnige man ### do sach man vil der daegene | danne mit sifride gan
###### 628 | ### die herren chomen beide | da si solden ligen ### do gedaht ietslicher | mit minnen angesigen ### den minnechlichen vrowen | daz sempftet in den mvt ### sifride chverzewile | div wart vil grozliche gvt
###### 629 | ### do der herre sifrit | bi criemhilde lach ### vnt er so minnechliche | der ivnchvrowen pflach ### mit sinen edelen minnen | si wart im so sin lip ### er naeme fvr si eine | niht tvsent andriv wip
###### 630 | ### ich sag iv niht mere | wi er der vrowen pflach ### nv horet disiv maere | wi gvnther gelach ### bi vrovn prvnnhilde | der ciere daegen ### er haete dicke sampfter | bi andern wiben gelaegen
###### 631 | ### daz volch was im entwichen | vrowen vnt man ### do wart div chemenate | vil balde zv getan ### er wande er solde trivten | ir vil minnechlichen lip ### ia was iz nach vnnahen | e si wurde sin wip
###### 632 | ### in sabenwizem hemede | si an daz bette gie ### do daht der ritter edele | nv han iz alliz hie ### des ich ie da gert | in allen minen tagen ### si mvst im von ir shoene | von grozen schvlden wol behagen
###### 633 | ### div lieht begonde bergen | des edeln chvniges hant ### do gie der daegen chvene | da er di vrowen vant ### er leite sich ir nahen | sin vrevde div was groz ### di vil minnechlichen | der helt mit armen vmbesloz
###### 634 | ### minnechlich trivten | des chvnd er vil began ### ob in div edele vrowe | hete lazzen daz getan ### da zvrnde si so sere | daz in gemvete daz ### er wande vinden frivnde | do vant er vintlichen haz
###### 635 | ### si sprach ritter edele | ir svlt iz lazen stan ### des ir da habet gedingen | ian mag es niht ergan ### ich wil noch magt beliben | ir svlt wol merchen daz ### vnz ich div maer erfinde | do wart ir gvnther gahaz
###### 636 | ### do rang er nach ir minne | vnt cerfvrt ir div chleit ### do greif nach einem gvrtel | div herlichiv meit ### daz was ein starcher porte | den si vmb ir siten trvch ### do tet si dem chvnige | grozer leide genvch
###### 637 | ### di fvoze vnt ovch di hende | si im cesamne bant ### si truoch in ceinem nagel | vnt hiench in an di want ### do er si slaffes irrite | di minne si im verbot ### ia het er von ir creffte | vil nach gewunnen den tot
###### 638 | ### do begond er vlegen | der meister wande sin ### nv loeset min gebende | vil edliv chvnegin ### ine truwe iv doch shoniv vrowe | nimmer an gesigen ### vnt sol ovch harte selten | iv so nahe mer geligen
###### 639 | ### si ne rvchte wi im waere | want si vil sanfte lach ### dort mvst er allez hangen | di naht vnz an den tach ### vnz der liehte morgen | dvrh div venster shein ### ob er ie crapft gewunne | div was an sinem libe chlein
###### 640 | ### nv sagt mir her gvnther | ist iv daz iht leit ### ob ivch gebvnden fvnden | sprach div shone meit ### di iwern chameraere | von einer vrowen hant ### do sprach der ritter edele | daz wurd iv vebele bewant
###### 641 | ### ovch het ih es wenich ere | sprach der snelle man ### dvrch iwer selber tvgende | nv lat mich zv iv gan ### sit daz iv mine minne | sint also starche leit ### ich sol mit minen henden | nimmer rveren iwer chleit
###### 642 | ### do losete si im balde | vnt do sin vf verlie ### wider daz bette | er zv der vrowen gie ### er leite sich so verre | daz er ir schone wat ### darnach vil selten rvrte | des wold ovch si do haben rat
###### 643 | ### do chom ovch ir gesinde | di brahten in niwiv chleit ### der was in an den morgen | harte vil bereit ### swi wol man da gebarte | trvrech was genvch ### der herre von dem lande | swi er des tages crhone trvch
###### 644 | ### nach siten der si pflagen | vnt man dvrch reht begie ### gvnther vnt prvnnhilt | niht langer daz en lie ### si giengen zv dem mvnster | da man di messe sanch ### dar chom ovch her sifrit | sich hvp da grozlich gedranch
###### 645 | ### nach chvnechlichen eren | was in dar bereit ### swaz si da haben solden | ir chrone vnt ovch ir chleit ### do wurden si gewihet | da daz was getan ### do sach man alle si viere | vnder chrone vrolichen stan
###### 646 | ### vil ivnger swertdegen da namen | sehs hvndert oder baz ### den chvnegin al ce den eren | ir svlt wol wizzen daz ### sich hvp vil michel vrevde | in der bvrgende lant ### man horte da scheffte hellen | an der swertdaegene hant
###### 647 | ### do sazen in den venstern | div schonen maegedin ### si sahen vor in livhten | vil maniges schildes schin ### do het sich gescheiden | der chvnich von sinen man ### swes iemen ander pflaege | man sah den chvnich trvrende gan
###### 648 | ### im vnt sifride | vngelich stvnt der mvt ### wol wesse waz im waere | der edel ritter gvt ### do giench er zv dem chvnige | vragen er began ### wi ist iv hint gelvngen | daz svlt ir mich nv wizen lan
###### 649 | ### do sprach der wirt ce dem gaste | ich han laster vnt shaden ### want ich han den vbeln tivel | heim ce hvse geladen ### do ich si wande minnen | vil sere si mich bant ### si trvoch mich ceinem nagele | vnt hie mich hohe an di want
###### 650 | ### da hie ich angestliche | di naht vnz an den tach ### e daz si mich embvnde | wi samfte si do lach ### daz sol dir vrivntliche | vf genade sin gechleit ### do sprach der starche sifrit | ez ist mir werliche leit
###### 651 | ### des bringe ich dich wol innen | vnt lezestv iz ane nit ### ich shaffe daz si hintz | so nahe bi dir gelit ### daz sie dich ir minne | gesvmet nimmer mer ### der rede was do gvnther | nach sinen arbeiten her
###### 652 | ### do sprach der herre sifrit | dv maht wol genesen ### ich wene vns vngeliche | hinat si gewesen ### mir ist din swester crimhilt | lieber danne der lip ### ez mvz div vrowe prvnnhilt | noch hinat werden din wip
###### 653 | ### er sprach ich chvm noch hinte | ce der chemenaten din ### also tovgenlichen | in der tarnkappen min ### daz sich miner liste | mach niemen wol versten ### so la di chameraere | vz zv ir herberge gen
###### 654 | ### so lessche ich den chinden | div lieht an der hant ### daz ich si darinne | dabi si dir bechant ### daz ich dir gerne diene | so twinge ich dir din wip ### daz dv si hinte minnest | oder ich verlivse minen lip
###### 655 | ### ane daz dv iht trvetest | sprach der chvnich do ### di mine lieben vrowen | anders pin ich es vro ### so tv ir swaz dv wellest | vnt naemest ir den lip ### daz sold ich wol verchiesen | si ist ein vreislichez wip
###### 656 | ### daz nim ich so sprach sifrit | vf di triwe min ### daz ich ir niht en minne | div shone swester din ### div ist mir vor allen | di ich noch ie gesach ### vil wol gelovbte der chvenich gvnther | daz sifrit gesprach
###### 657 | ### da was von kvrcewile | vrevde vnt not ### bvhvrt vnt shallen | allez man verbot ### da di vrowen solden | gegen dem sale gan ### do hiezen di kameraere | di livte von dem wege stan
###### 658 | ### von rossen vnt von livten | gervmet wart der hoff ### der vrowen ietsliche | di fvrt ein bissoff ### do si vor den chvnegen | ce tissche solden gan ### in volgete an daz gesidele | vil manich waetlicher man
###### 659 | ### der chvnich in gvtem wane | do vrolichen saz ### daz im gelobte sifrit | wol daht er ane daz ### der eine tach in dvhte | wol drizech tage lanch ### an siner vrowen minne | stvnt aller sin gedanch
###### 660 | ### er erbeite chvme | daz man von tisshe gie ### di schonen prvnnhilde | man do chomen lie ### vnt ovch vrovn crimhilde | bede an ir gemach ### hey waz man sneller daegne | vor den chvnegen sach
###### 661 | ### sifrit der herre | vil minnechlichen saz ### bi sinem wibe | mit vrevden ane haz ### si trvte sine hende | mit ir vil wizzer hant ### vnze er ir vor den ovgen | si ne wesse wenne verswant
###### 662 | ### do si mit im spilte | vnt sis niht mer en sach ### zv sinem gesinde | div chveneginne sprach ### mich hat des michel wunder | wa der chvnich si bechomen ### wer hat im di sinen hende | vz den minen genomen
###### 663 | ### di rede si lie beliben | do was er hin gegan ### da er vil chameraere | mit den liehten vant stan ### div begond er lehssen | den kinden an der hant ### daz er waere sifrit | daz was gvnther bechant
###### 664 | ### wol wesse er waz er wolde | do hiez er dannen gan ### maegede vnt vrowen | do daz was getan ### der riche chvnech selbe | do besloz di tver ### vil starcher rigel zwene | warf er snelle darfvor
###### 665 | ### div lieht verbarch er schiere | vnder di bette wat ### eines spils begonde | des was do niht rat ### sifrit der vil starche | vnt ovch div vil schoniv meit ### daz was dem chvnige gvnther | beidiv lip vnt leit
###### 666 | ### sifrit der leit sich nahen | der ivnchvrowen bi ### si sprach nv lat iz gvnther | als liep als ich iv si ### daz ir iht arbeite | lidet alsam e ### sit getet div vrowe | dem chvnen sifride we
###### 667 | ### do hal er sine stimme | daz er niht en sprah ### gvnther wol horte | swi er sin niht en sah ### daz heimlicher dinge | von in da niht geschach ### si heten an dem bette | vil harte chleinen gemach
###### 668 | ### er gebarte sam ez waere | gvnther der chvnich rich ### er vmbsloz mit armen | di magt lobelich ### si warf in vz dem bette | da bi vf eine banch ### daz im sin hovbt lvte | vf einem schamel erclanch
###### 669 | ### wider vf mit crepffen | spranch der chvne man ### er wold iz baz versvchen | do er des began ### daz er si wolde twingen | darvmbe wart im vil we ### solech wer von deheiner vrowen | div waene immer mer erge
###### 670 | ### do er niht wold erwinden | div maget vf do spranch ### ir en svlt mir niht cerfveren | min hemde so blanch ### ir sit vil vngefvege | daz sol iv werden leit ### des bringe ich ivch wol innen | sprach div waetlichiv meit
###### 671 | ### si besloz mit armen | den tiwerlichen daegen ### do wold si in gebvnden | alsam den chvnich legen ### daz si an dem bette | mohte haben gemach ### daz er ir di wat cerfvrte | div vrowe iz grozlichen rach
###### 672 | ### waz half sin groziv sterche | vnt ovch sin groziv crapft ### si erceigete dem degene | ir libes meisterschapft ### si trvch in mit gewalte | daz mvs et also sin ### vnt drvcht in gevoge | zwisschen di want vnd ein schrin
###### 673 | ### owe daht der recke | sol ich nv minen lip ### von einer magt verliesen | so mvgen elliv wip ### hernach immer mere | tragen gelffen mvt ### gegen ir manne | div ez svs nimmer getvt
###### 674 | ### der chvnich ez wol horte | er angestete vmb den man ### sifrit zvrnte sere | shamen er sich began ### mit vngefveger crepfte | sazt er sich wider ### er versvchtez angestiliche | an vrovn prvnnhilde sider
###### 675 | ### den chvnich ez dvhte lange | e er si betwanch ### si drvcht im sine hende | daz vz den nageln sprach ### daz plvt im von ir crepfte | daz was dem helde leit ### sit braht er an ein lovgen | di vil herlichen meit
###### 676 | ### ir vngefveges willen | des si e da iach ### der kvnich iz allez horte | swi er niht en sprach ### er druchtes an daz bette | daz si vil lvte schre ### ir taten sine crepfte | harte grozlichen we
###### 677 | ### do greif si hinz ir siten | da si den porten vant ### vnt wolt in han gebvnden | do wert ez so sin hant ### daz ir div lid ercrachten | vnt ovch al der lip ### des wart der strit gescheiden | do wart si gvntheres wip
###### 678 | ### si sprach chvnich edele | dv solt mich laeben lan ### ez wirt vil wol versvenet | swaz ich dir han getan ### ich en gewer mich nimmer maere | der aedelen minne din ### ich han daz wol erfvnden | daz dv chanst vrowen meister sin
###### 679 | ### sifrit stvnt dannen | ligen lie er di meit ### sam er von im ziehen | wolde vil gar siniv chleit ### er zoch ir abe ir hende | ein gvldin vingerlin ### daz si des nie wart innen | div edle chvnegin
###### 680 | ### darzv nam er ir gvrtel | daz was ein porte gvt ### ine weiz ob er daz taete | dvrh sinen hohen mvt ### er gab iz sinem wibe | daz wart im sider leit ### do lagen bi einander | gvnther vnt div schoniv meit
###### 681 | ### er pflach ir minnechlichen | als im daz gezam ### do mvst si verchiesen | ir zorn vnt ovch ir sham ### von siner heimliche | si wart ein lvocel bleich ### hey waz ir von der minne | ir grozen crepffte entweich
###### 682 | ### do ne was ovch si niht staercher | dann ein ander wip ### er trvte minnechliche | den ir vil shonen lip ### ob siz versvchte maere | waz chvnde daz vervan ### daz het ir allez gvnther | mit sinen minnen getan
###### 683 | ### wi rehte minnechliche | si do bi im lach ### mit vrivntlicher liebe | vnz an den liehten tach ### nv was der herre sifrit | wider vz gegan ### da er wol wart entpfangen | von einer vrowen wolgetan
###### 684 | ### er vnderstvnt ir vrage | der si haete gedaht ### er hal si sit vil lange | daz er ir haete braht ### vnz daz si vnder chrone | in sinem lande gie ### swaz er ir gaeben solde | wi lvcel erz beliben lie
###### 685 | ### der wirt wart an dem morgen | verrer baz gemvt ### danne er davor waere | des wart div vrevde gvt ### in allem sinem lande | von manigem edlem man ### di er ce hvse ladete | den wart vil dieneste getan
###### 686 | ### div hohzit do waerte | vnz an den viercehenden tach ### daz in al der wile nie | der shal gelach ### von allerhende vrevden | der iemen solde pflaegen ### do wart des chvneges choste | vil harte hohe gewaegen
###### 687 | ### des edelen wirtes mage | als ez der chvenich gebot ### den gaben dvrch sin ere | chleider vnt golt vil rot ### ross vnt darzv silber | vil manigem vremdem man ### di da gabe gerten | di shieden vrolichen dan
###### 688 | ### sifrit der herre | vzer niderlant ### mit tvsent sinen mannen | alliz ir gewant ### daz si ce rine brahten | wart alliz hin gegaeben ### vnt ovch div ross mit saetelen | si chvnden herliche leben
###### 689 | ### e daz man di riche gabe | alle da verswanch ### di wider ce lande wolden | di dvhte des ce lanch ### ez en wart nie geste | maere baz gepflaegen ### so endete sich div hohzit | daz wolde gvnther der daegen

<<< Übersicht <<< vorige Seite nächste Seite >>>